

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from krutrim_client import KrutrimClient, AsyncKrutrimClient
from krutrim_client.types import (
    ImageList,
    VpcDetail,
    PortDetail,
    InstanceInfo,
    SuccessResponse,
    InstanceInfoList,
    HighlvlvpcListVpcsResponse,
    HighlvlvpcSearchVpcsResponse,
    HighlvlvpcSearchPortsResponse,
    HighlvlvpcSearchNetworksResponse,
    HighlvlvpcListSubnetConnectionsResponse,
)
from krutrim_client._utils import parse_datetime

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestHighlvlvpc:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    
    @pytest.mark.skip()
    @parametrize
    def test_method_create_instance(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.create_instance(
            image_krn="krn:vm:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:image:89132209-ad64-4a2b-8d06-85d0b83b8817",
            instance_name="test_instance_surya_1_19nov",
            instance_type="CPU-1x-4GB",
            network_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:network:dfc60763-6174-43d5-8b07-55b81d10aeba",
            region="in-hyd-1",
            security_groups=[
                "krn:krutrim-sg:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:sg:c88dd669-612a-4829-afc7-453aabac6eb6"
            ],
            sshkey_name="bhaskara",
            subnet_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:subnet:f61d540c-a82d-4959-bd70-3a00b6bfcfb2",
            vm_volume_disk_size="10",
            vpc_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:vpc:323fc1d4-8b0a-4f26-9406-42a2732d65f5",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(InstanceInfo, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create_instance_with_all_params(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.create_instance(
            image_krn="krn:vm:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:image:89132209-ad64-4a2b-8d06-85d0b83b8817",
            instance_name="test_instance_surya_1_19nov",
            instance_type="CPU-1x-4GB",
            network_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:network:dfc60763-6174-43d5-8b07-55b81d10aeba",
            region="in-hyd-1",
            security_groups=[
                "krn:krutrim-sg:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:sg:c88dd669-612a-4829-afc7-453aabac6eb6"
            ],
            sshkey_name="bhaskara",
            subnet_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:subnet:f61d540c-a82d-4959-bd70-3a00b6bfcfb2",
            vm_volume_disk_size="10",
            vpc_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:vpc:323fc1d4-8b0a-4f26-9406-42a2732d65f5",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
            floating_ip=False,
            security_group_rules_name="ingress",
            security_group_rules_port="22",
            security_group_rules_protocol="tcp",
            user_data="IyEvYmluL2Jhc2gKdXNlcmFkZCAtbSAtcyAvYmluL2Jhc2gga3J1dHJpbQplY2hvICJrcnV0cmltOnBhc3N3b3JkIiB8IGNocGFzc3dkCnRvdWNoIC90bXAvc2FtcGxlLnR4dAo=",
            volume_name="volume_test_instance_vpc_06",
            volume_size="5",
        )
        assert_matches_type(InstanceInfo, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create_instance(self, client: KrutrimClient) -> None:
        response = client.highlvlvpc.with_raw_response.create_instance(
            image_krn="krn:vm:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:image:89132209-ad64-4a2b-8d06-85d0b83b8817",
            instance_name="test_instance_surya_1_19nov",
            instance_type="CPU-1x-4GB",
            network_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:network:dfc60763-6174-43d5-8b07-55b81d10aeba",
            region="in-hyd-1",
            security_groups=[
                "krn:krutrim-sg:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:sg:c88dd669-612a-4829-afc7-453aabac6eb6"
            ],
            sshkey_name="bhaskara",
            subnet_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:subnet:f61d540c-a82d-4959-bd70-3a00b6bfcfb2",
            vm_volume_disk_size="10",
            vpc_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:vpc:323fc1d4-8b0a-4f26-9406-42a2732d65f5",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = response.parse()
        assert_matches_type(InstanceInfo, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create_instance(self, client: KrutrimClient) -> None:
        with client.highlvlvpc.with_streaming_response.create_instance(
            image_krn="krn:vm:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:image:89132209-ad64-4a2b-8d06-85d0b83b8817",
            instance_name="test_instance_surya_1_19nov",
            instance_type="CPU-1x-4GB",
            network_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:network:dfc60763-6174-43d5-8b07-55b81d10aeba",
            region="in-hyd-1",
            security_groups=[
                "krn:krutrim-sg:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:sg:c88dd669-612a-4829-afc7-453aabac6eb6"
            ],
            sshkey_name="bhaskara",
            subnet_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:subnet:f61d540c-a82d-4959-bd70-3a00b6bfcfb2",
            vm_volume_disk_size="10",
            vpc_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:vpc:323fc1d4-8b0a-4f26-9406-42a2732d65f5",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = response.parse()
            assert_matches_type(InstanceInfo, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_create_port(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.create_port(
            floating_ip=False,
            name="vm_jan_3_exp-1_port",
            network_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:network:xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            subnet_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:subnet:yyyyyyyy-yyyy-yyyy-yyyy-yyyyyyyyyyyy",
            vpc_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:vpc:e0408184-6593-4aaa-a607-ca6e76afe30e",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(PortDetail, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create_port(self, client: KrutrimClient) -> None:
        response = client.highlvlvpc.with_raw_response.create_port(
            floating_ip=False,
            name="vm_jan_3_exp-1_port",
            network_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:network:xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            subnet_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:subnet:yyyyyyyy-yyyy-yyyy-yyyy-yyyyyyyyyyyy",
            vpc_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:vpc:e0408184-6593-4aaa-a607-ca6e76afe30e",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = response.parse()
        assert_matches_type(PortDetail, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create_port(self, client: KrutrimClient) -> None:
        with client.highlvlvpc.with_streaming_response.create_port(
            floating_ip=False,
            name="vm_jan_3_exp-1_port",
            network_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:network:xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            subnet_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:subnet:yyyyyyyy-yyyy-yyyy-yyyy-yyyyyyyyyyyy",
            vpc_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:vpc:e0408184-6593-4aaa-a607-ca6e76afe30e",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = response.parse()
            assert_matches_type(PortDetail, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_create_subnet(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.create_subnet(
            subnet_data={
                "cidr": "10.0.1.0/24",
                "ip_version": 4,
                "name": "my-app-subnet",
            },
            vpc_id="vpc_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert highlvlvpc is None

    @pytest.mark.skip()
    @parametrize
    def test_method_create_subnet_with_all_params(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.create_subnet(
            subnet_data={
                "cidr": "10.0.1.0/24",
                "ip_version": 4,
                "name": "my-app-subnet",
                "description": "Subnet for application servers",
                "gateway_ip": "10.0.1.1",
            },
            vpc_id="vpc_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert highlvlvpc is None

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create_subnet(self, client: KrutrimClient) -> None:
        response = client.highlvlvpc.with_raw_response.create_subnet(
            subnet_data={
                "cidr": "10.0.1.0/24",
                "ip_version": 4,
                "name": "my-app-subnet",
            },
            vpc_id="vpc_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = response.parse()
        assert highlvlvpc is None

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create_subnet(self, client: KrutrimClient) -> None:
        with client.highlvlvpc.with_streaming_response.create_subnet(
            subnet_data={
                "cidr": "10.0.1.0/24",
                "ip_version": 4,
                "name": "my-app-subnet",
            },
            vpc_id="vpc_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = response.parse()
            assert highlvlvpc is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_create_vpc(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.create_vpc(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create_vpc_with_all_params(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.create_vpc(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
            network={
                "admin_state_up": True,
                "name": "name",
            },
            security_group={
                "description": "description",
                "name": "name",
            },
            security_group_rule={
                "direction": "ingress",
                "ethertypes": "IPv4",
                "port_max_range": 0,
                "port_min_range": 0,
                "protocol": "protocol",
                "remote_ip_prefix": "remoteIPPrefix",
            },
            subnet={
                "cidr": "cidr",
                "description": "description",
                "gateway_ip": "192.168.1.1",
                "ip_version": 4,
                "name": "name",
                "egress": True,
                "ingress": True,
            },
            vpc={
                "description": "description",
                "enabled": True,
                "name": "name",
            },
        )
        assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create_vpc(self, client: KrutrimClient) -> None:
        response = client.highlvlvpc.with_raw_response.create_vpc(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = response.parse()
        assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create_vpc(self, client: KrutrimClient) -> None:
        with client.highlvlvpc.with_streaming_response.create_vpc(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = response.parse()
            assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_delete_instance(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.delete_instance(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_delete_instance_with_all_params(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.delete_instance(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
            instance_krn="krn:vm:Colo1-qa:0005604999:718a1c1c-55db-47c7-8b01-bd5f44d8e076:instance:b7830594-6e28-4d81-893d-e48cb6b02e49",
            instance_name="my-instance-dec-17-1",
        )
        assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_delete_instance(self, client: KrutrimClient) -> None:
        response = client.highlvlvpc.with_raw_response.delete_instance(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = response.parse()
        assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_delete_instance(self, client: KrutrimClient) -> None:
        with client.highlvlvpc.with_streaming_response.delete_instance(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = response.parse()
            assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_delete_vpc(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.delete_vpc(
            vpc_id="vpc_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert highlvlvpc is None

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_delete_vpc(self, client: KrutrimClient) -> None:
        response = client.highlvlvpc.with_raw_response.delete_vpc(
            vpc_id="vpc_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = response.parse()
        assert highlvlvpc is None

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_delete_vpc(self, client: KrutrimClient) -> None:
        with client.highlvlvpc.with_streaming_response.delete_vpc(
            vpc_id="vpc_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = response.parse()
            assert highlvlvpc is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_get_vpc_task_status(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.get_vpc_task_status(
            task_id="task_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_get_vpc_task_status(self, client: KrutrimClient) -> None:
        response = client.highlvlvpc.with_raw_response.get_vpc_task_status(
            task_id="task_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = response.parse()
        assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_get_vpc_task_status(self, client: KrutrimClient) -> None:
        with client.highlvlvpc.with_streaming_response.get_vpc_task_status(
            task_id="task_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = response.parse()
            assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

   
    @pytest.mark.skip()
    @parametrize
    def test_method_list_instance_info(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.list_instance_info(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(InstanceInfoList, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_list_instance_info_with_all_params(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.list_instance_info(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
            page=1,
            page_size=1,
            vpc_id="vpc_id",
        )
        assert_matches_type(InstanceInfoList, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list_instance_info(self, client: KrutrimClient) -> None:
        response = client.highlvlvpc.with_raw_response.list_instance_info(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = response.parse()
        assert_matches_type(InstanceInfoList, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list_instance_info(self, client: KrutrimClient) -> None:
        with client.highlvlvpc.with_streaming_response.list_instance_info(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = response.parse()
            assert_matches_type(InstanceInfoList, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_list_subnet_connections(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.list_subnet_connections(
            vpc_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:vpc:e0408184-6593-4aaa-a607-ca6e76afe30e",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(HighlvlvpcListSubnetConnectionsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list_subnet_connections(self, client: KrutrimClient) -> None:
        response = client.highlvlvpc.with_raw_response.list_subnet_connections(
            vpc_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:vpc:e0408184-6593-4aaa-a607-ca6e76afe30e",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = response.parse()
        assert_matches_type(HighlvlvpcListSubnetConnectionsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list_subnet_connections(self, client: KrutrimClient) -> None:
        with client.highlvlvpc.with_streaming_response.list_subnet_connections(
            vpc_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:vpc:e0408184-6593-4aaa-a607-ca6e76afe30e",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = response.parse()
            assert_matches_type(HighlvlvpcListSubnetConnectionsResponse, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_list_vpcs(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.list_vpcs(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(HighlvlvpcListVpcsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list_vpcs(self, client: KrutrimClient) -> None:
        response = client.highlvlvpc.with_raw_response.list_vpcs(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = response.parse()
        assert_matches_type(HighlvlvpcListVpcsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list_vpcs(self, client: KrutrimClient) -> None:
        with client.highlvlvpc.with_streaming_response.list_vpcs(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = response.parse()
            assert_matches_type(HighlvlvpcListVpcsResponse, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve_instance(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.retrieve_instance(
            krn="krn",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(InstanceInfo, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_retrieve_instance(self, client: KrutrimClient) -> None:
        response = client.highlvlvpc.with_raw_response.retrieve_instance(
            krn="krn",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = response.parse()
        assert_matches_type(InstanceInfo, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_retrieve_instance(self, client: KrutrimClient) -> None:
        with client.highlvlvpc.with_streaming_response.retrieve_instance(
            krn="krn",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = response.parse()
            assert_matches_type(InstanceInfo, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve_vpc(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.retrieve_vpc(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(VpcDetail, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve_vpc_with_all_params(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.retrieve_vpc(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
            vpc_id="krn:vpc:Colo1-qa:5373689502:46208820-5e16-4dac-b110-e6de4889d50a:vpc:952a6224-ed83-4870-9226-c8f97ac25b8e",
            vpc_name="HL_VPC_Dec_4",
        )
        assert_matches_type(VpcDetail, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_retrieve_vpc(self, client: KrutrimClient) -> None:
        response = client.highlvlvpc.with_raw_response.retrieve_vpc(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = response.parse()
        assert_matches_type(VpcDetail, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_retrieve_vpc(self, client: KrutrimClient) -> None:
        with client.highlvlvpc.with_streaming_response.retrieve_vpc(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = response.parse()
            assert_matches_type(VpcDetail, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_search_instances(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.search_instances(
            vpc_id="krn:vpc:Colo1-qa:0005604999:718a1c1c-55db-47c7-8b01-bd5f44d8e076:vpc:d5e2c968-9db4-4c05-99fc-293107c33f3e",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
            x_user_email="dev@stainless.com",
        )
        assert_matches_type(InstanceInfoList, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_search_instances_with_all_params(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.search_instances(
            vpc_id="krn:vpc:Colo1-qa:0005604999:718a1c1c-55db-47c7-8b01-bd5f44d8e076:vpc:d5e2c968-9db4-4c05-99fc-293107c33f3e",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
            x_user_email="dev@stainless.com",
            limit=1,
            page=1,
            ip_fixed="20.169.1.5",
            ip_floating="100.20.30.40",
            krn="krn:vm:Colo1-qa:0005604999:718a1c1c-55db-47c7-8b01-bd5f44d8e076:instance:d84de151-9086-4c66-aa3b-cb615fc1d747",
            name="vm_jan_3_exp-1",
        )
        assert_matches_type(InstanceInfoList, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_search_instances(self, client: KrutrimClient) -> None:
        response = client.highlvlvpc.with_raw_response.search_instances(
            vpc_id="krn:vpc:Colo1-qa:0005604999:718a1c1c-55db-47c7-8b01-bd5f44d8e076:vpc:d5e2c968-9db4-4c05-99fc-293107c33f3e",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
            x_user_email="dev@stainless.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = response.parse()
        assert_matches_type(InstanceInfoList, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_search_instances(self, client: KrutrimClient) -> None:
        with client.highlvlvpc.with_streaming_response.search_instances(
            vpc_id="krn:vpc:Colo1-qa:0005604999:718a1c1c-55db-47c7-8b01-bd5f44d8e076:vpc:d5e2c968-9db4-4c05-99fc-293107c33f3e",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
            x_user_email="dev@stainless.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = response.parse()
            assert_matches_type(InstanceInfoList, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_search_networks(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.search_networks(
            vpc_id="vpc_id",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(HighlvlvpcSearchNetworksResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_search_networks(self, client: KrutrimClient) -> None:
        response = client.highlvlvpc.with_raw_response.search_networks(
            vpc_id="vpc_id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = response.parse()
        assert_matches_type(HighlvlvpcSearchNetworksResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_search_networks(self, client: KrutrimClient) -> None:
        with client.highlvlvpc.with_streaming_response.search_networks(
            vpc_id="vpc_id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = response.parse()
            assert_matches_type(HighlvlvpcSearchNetworksResponse, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_search_ports(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.search_ports(
            x_account_id="acc-1234567890",
        )
        assert_matches_type(HighlvlvpcSearchPortsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_search_ports_with_all_params(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.search_ports(
            x_account_id="acc-1234567890",
            name="name",
            network_id="network_id",
            page=1,
            port_id="port_id",
            size=1,
            status="status",
            vpc_id="vpc_id",
        )
        assert_matches_type(HighlvlvpcSearchPortsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_search_ports(self, client: KrutrimClient) -> None:
        response = client.highlvlvpc.with_raw_response.search_ports(
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = response.parse()
        assert_matches_type(HighlvlvpcSearchPortsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_search_ports(self, client: KrutrimClient) -> None:
        with client.highlvlvpc.with_streaming_response.search_ports(
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = response.parse()
            assert_matches_type(HighlvlvpcSearchPortsResponse, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_search_vpcs(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.search_vpcs()
        assert_matches_type(HighlvlvpcSearchVpcsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_search_vpcs_with_all_params(self, client: KrutrimClient) -> None:
        highlvlvpc = client.highlvlvpc.search_vpcs(
            name="name",
            page=1,
            size=1,
            status="status",
        )
        assert_matches_type(HighlvlvpcSearchVpcsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_search_vpcs(self, client: KrutrimClient) -> None:
        response = client.highlvlvpc.with_raw_response.search_vpcs()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = response.parse()
        assert_matches_type(HighlvlvpcSearchVpcsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_search_vpcs(self, client: KrutrimClient) -> None:
        with client.highlvlvpc.with_streaming_response.search_vpcs() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = response.parse()
            assert_matches_type(HighlvlvpcSearchVpcsResponse, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncHighlvlvpc:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])



    @pytest.mark.skip()
    @parametrize
    async def test_method_create_instance(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.create_instance(
            image_krn="krn:vm:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:image:89132209-ad64-4a2b-8d06-85d0b83b8817",
            instance_name="test_instance_surya_1_19nov",
            instance_type="CPU-1x-4GB",
            network_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:network:dfc60763-6174-43d5-8b07-55b81d10aeba",
            region="in-hyd-1",
            security_groups=[
                "krn:krutrim-sg:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:sg:c88dd669-612a-4829-afc7-453aabac6eb6"
            ],
            sshkey_name="bhaskara",
            subnet_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:subnet:f61d540c-a82d-4959-bd70-3a00b6bfcfb2",
            vm_volume_disk_size="10",
            vpc_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:vpc:323fc1d4-8b0a-4f26-9406-42a2732d65f5",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(InstanceInfo, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_instance_with_all_params(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.create_instance(
            image_krn="krn:vm:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:image:89132209-ad64-4a2b-8d06-85d0b83b8817",
            instance_name="test_instance_surya_1_19nov",
            instance_type="CPU-1x-4GB",
            network_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:network:dfc60763-6174-43d5-8b07-55b81d10aeba",
            region="in-hyd-1",
            security_groups=[
                "krn:krutrim-sg:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:sg:c88dd669-612a-4829-afc7-453aabac6eb6"
            ],
            sshkey_name="bhaskara",
            subnet_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:subnet:f61d540c-a82d-4959-bd70-3a00b6bfcfb2",
            vm_volume_disk_size="10",
            vpc_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:vpc:323fc1d4-8b0a-4f26-9406-42a2732d65f5",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
            floating_ip=False,
            security_group_rules_name="ingress",
            security_group_rules_port="22",
            security_group_rules_protocol="tcp",
            user_data="IyEvYmluL2Jhc2gKdXNlcmFkZCAtbSAtcyAvYmluL2Jhc2gga3J1dHJpbQplY2hvICJrcnV0cmltOnBhc3N3b3JkIiB8IGNocGFzc3dkCnRvdWNoIC90bXAvc2FtcGxlLnR4dAo=",
            volume_name="volume_test_instance_vpc_06",
            volume_size="5",
        )
        assert_matches_type(InstanceInfo, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create_instance(self, async_client: AsyncKrutrimClient) -> None:
        response = await async_client.highlvlvpc.with_raw_response.create_instance(
            image_krn="krn:vm:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:image:89132209-ad64-4a2b-8d06-85d0b83b8817",
            instance_name="test_instance_surya_1_19nov",
            instance_type="CPU-1x-4GB",
            network_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:network:dfc60763-6174-43d5-8b07-55b81d10aeba",
            region="in-hyd-1",
            security_groups=[
                "krn:krutrim-sg:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:sg:c88dd669-612a-4829-afc7-453aabac6eb6"
            ],
            sshkey_name="bhaskara",
            subnet_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:subnet:f61d540c-a82d-4959-bd70-3a00b6bfcfb2",
            vm_volume_disk_size="10",
            vpc_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:vpc:323fc1d4-8b0a-4f26-9406-42a2732d65f5",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = await response.parse()
        assert_matches_type(InstanceInfo, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create_instance(self, async_client: AsyncKrutrimClient) -> None:
        async with async_client.highlvlvpc.with_streaming_response.create_instance(
            image_krn="krn:vm:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:image:89132209-ad64-4a2b-8d06-85d0b83b8817",
            instance_name="test_instance_surya_1_19nov",
            instance_type="CPU-1x-4GB",
            network_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:network:dfc60763-6174-43d5-8b07-55b81d10aeba",
            region="in-hyd-1",
            security_groups=[
                "krn:krutrim-sg:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:sg:c88dd669-612a-4829-afc7-453aabac6eb6"
            ],
            sshkey_name="bhaskara",
            subnet_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:subnet:f61d540c-a82d-4959-bd70-3a00b6bfcfb2",
            vm_volume_disk_size="10",
            vpc_id="krn:vpc:Colo2-perf:1587599074:c094d34c-b137-4635-b020-3b733375dd89:vpc:323fc1d4-8b0a-4f26-9406-42a2732d65f5",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = await response.parse()
            assert_matches_type(InstanceInfo, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_port(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.create_port(
            floating_ip=False,
            name="vm_jan_3_exp-1_port",
            network_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:network:xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            subnet_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:subnet:yyyyyyyy-yyyy-yyyy-yyyy-yyyyyyyyyyyy",
            vpc_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:vpc:e0408184-6593-4aaa-a607-ca6e76afe30e",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(PortDetail, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create_port(self, async_client: AsyncKrutrimClient) -> None:
        response = await async_client.highlvlvpc.with_raw_response.create_port(
            floating_ip=False,
            name="vm_jan_3_exp-1_port",
            network_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:network:xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            subnet_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:subnet:yyyyyyyy-yyyy-yyyy-yyyy-yyyyyyyyyyyy",
            vpc_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:vpc:e0408184-6593-4aaa-a607-ca6e76afe30e",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = await response.parse()
        assert_matches_type(PortDetail, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create_port(self, async_client: AsyncKrutrimClient) -> None:
        async with async_client.highlvlvpc.with_streaming_response.create_port(
            floating_ip=False,
            name="vm_jan_3_exp-1_port",
            network_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:network:xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            subnet_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:subnet:yyyyyyyy-yyyy-yyyy-yyyy-yyyyyyyyyyyy",
            vpc_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:vpc:e0408184-6593-4aaa-a607-ca6e76afe30e",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = await response.parse()
            assert_matches_type(PortDetail, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_subnet(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.create_subnet(
            subnet_data={
                "cidr": "10.0.1.0/24",
                "ip_version": 4,
                "name": "my-app-subnet",
            },
            vpc_id="vpc_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert highlvlvpc is None

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_subnet_with_all_params(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.create_subnet(
            subnet_data={
                "cidr": "10.0.1.0/24",
                "ip_version": 4,
                "name": "my-app-subnet",
                "description": "Subnet for application servers",
                "gateway_ip": "10.0.1.1",
            },
            vpc_id="vpc_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert highlvlvpc is None

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create_subnet(self, async_client: AsyncKrutrimClient) -> None:
        response = await async_client.highlvlvpc.with_raw_response.create_subnet(
            subnet_data={
                "cidr": "10.0.1.0/24",
                "ip_version": 4,
                "name": "my-app-subnet",
            },
            vpc_id="vpc_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = await response.parse()
        assert highlvlvpc is None

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create_subnet(self, async_client: AsyncKrutrimClient) -> None:
        async with async_client.highlvlvpc.with_streaming_response.create_subnet(
            subnet_data={
                "cidr": "10.0.1.0/24",
                "ip_version": 4,
                "name": "my-app-subnet",
            },
            vpc_id="vpc_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = await response.parse()
            assert highlvlvpc is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_vpc(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.create_vpc(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_vpc_with_all_params(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.create_vpc(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
            network={
                "admin_state_up": True,
                "name": "name",
            },
            security_group={
                "description": "description",
                "name": "name",
            },
            security_group_rule={
                "direction": "ingress",
                "ethertypes": "IPv4",
                "port_max_range": 0,
                "port_min_range": 0,
                "protocol": "protocol",
                "remote_ip_prefix": "remoteIPPrefix",
            },
            subnet={
                "cidr": "cidr",
                "description": "description",
                "gateway_ip": "192.168.1.1",
                "ip_version": 4,
                "name": "name",
                "egress": True,
                "ingress": True,
            },
            vpc={
                "description": "description",
                "enabled": True,
                "name": "name",
            },
        )
        assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create_vpc(self, async_client: AsyncKrutrimClient) -> None:
        response = await async_client.highlvlvpc.with_raw_response.create_vpc(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = await response.parse()
        assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create_vpc(self, async_client: AsyncKrutrimClient) -> None:
        async with async_client.highlvlvpc.with_streaming_response.create_vpc(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = await response.parse()
            assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_delete_instance(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.delete_instance(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_delete_instance_with_all_params(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.delete_instance(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
            instance_krn="krn:vm:Colo1-qa:0005604999:718a1c1c-55db-47c7-8b01-bd5f44d8e076:instance:b7830594-6e28-4d81-893d-e48cb6b02e49",
            instance_name="my-instance-dec-17-1",
        )
        assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_delete_instance(self, async_client: AsyncKrutrimClient) -> None:
        response = await async_client.highlvlvpc.with_raw_response.delete_instance(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = await response.parse()
        assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_delete_instance(self, async_client: AsyncKrutrimClient) -> None:
        async with async_client.highlvlvpc.with_streaming_response.delete_instance(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = await response.parse()
            assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_delete_vpc(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.delete_vpc(
            vpc_id="vpc_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert highlvlvpc is None

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_delete_vpc(self, async_client: AsyncKrutrimClient) -> None:
        response = await async_client.highlvlvpc.with_raw_response.delete_vpc(
            vpc_id="vpc_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = await response.parse()
        assert highlvlvpc is None

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_delete_vpc(self, async_client: AsyncKrutrimClient) -> None:
        async with async_client.highlvlvpc.with_streaming_response.delete_vpc(
            vpc_id="vpc_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = await response.parse()
            assert highlvlvpc is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_vpc_task_status(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.get_vpc_task_status(
            task_id="task_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_get_vpc_task_status(self, async_client: AsyncKrutrimClient) -> None:
        response = await async_client.highlvlvpc.with_raw_response.get_vpc_task_status(
            task_id="task_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = await response.parse()
        assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_get_vpc_task_status(self, async_client: AsyncKrutrimClient) -> None:
        async with async_client.highlvlvpc.with_streaming_response.get_vpc_task_status(
            task_id="task_id",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = await response.parse()
            assert_matches_type(SuccessResponse, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

   

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_instance_info(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.list_instance_info(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(InstanceInfoList, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_instance_info_with_all_params(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.list_instance_info(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
            page=1,
            page_size=1,
            vpc_id="vpc_id",
        )
        assert_matches_type(InstanceInfoList, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list_instance_info(self, async_client: AsyncKrutrimClient) -> None:
        response = await async_client.highlvlvpc.with_raw_response.list_instance_info(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = await response.parse()
        assert_matches_type(InstanceInfoList, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list_instance_info(self, async_client: AsyncKrutrimClient) -> None:
        async with async_client.highlvlvpc.with_streaming_response.list_instance_info(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = await response.parse()
            assert_matches_type(InstanceInfoList, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_subnet_connections(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.list_subnet_connections(
            vpc_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:vpc:e0408184-6593-4aaa-a607-ca6e76afe30e",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(HighlvlvpcListSubnetConnectionsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list_subnet_connections(self, async_client: AsyncKrutrimClient) -> None:
        response = await async_client.highlvlvpc.with_raw_response.list_subnet_connections(
            vpc_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:vpc:e0408184-6593-4aaa-a607-ca6e76afe30e",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = await response.parse()
        assert_matches_type(HighlvlvpcListSubnetConnectionsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list_subnet_connections(self, async_client: AsyncKrutrimClient) -> None:
        async with async_client.highlvlvpc.with_streaming_response.list_subnet_connections(
            vpc_id="krn:vpc:colo-2-acceptance:9550999532:cbcf451f-f15d-40e1-af39-4242e727732c:vpc:e0408184-6593-4aaa-a607-ca6e76afe30e",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = await response.parse()
            assert_matches_type(HighlvlvpcListSubnetConnectionsResponse, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_vpcs(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.list_vpcs(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(HighlvlvpcListVpcsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list_vpcs(self, async_client: AsyncKrutrimClient) -> None:
        response = await async_client.highlvlvpc.with_raw_response.list_vpcs(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = await response.parse()
        assert_matches_type(HighlvlvpcListVpcsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list_vpcs(self, async_client: AsyncKrutrimClient) -> None:
        async with async_client.highlvlvpc.with_streaming_response.list_vpcs(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = await response.parse()
            assert_matches_type(HighlvlvpcListVpcsResponse, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve_instance(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.retrieve_instance(
            krn="krn",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(InstanceInfo, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_retrieve_instance(self, async_client: AsyncKrutrimClient) -> None:
        response = await async_client.highlvlvpc.with_raw_response.retrieve_instance(
            krn="krn",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = await response.parse()
        assert_matches_type(InstanceInfo, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_retrieve_instance(self, async_client: AsyncKrutrimClient) -> None:
        async with async_client.highlvlvpc.with_streaming_response.retrieve_instance(
            krn="krn",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = await response.parse()
            assert_matches_type(InstanceInfo, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve_vpc(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.retrieve_vpc(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(VpcDetail, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve_vpc_with_all_params(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.retrieve_vpc(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
            vpc_id="krn:vpc:Colo1-qa:5373689502:46208820-5e16-4dac-b110-e6de4889d50a:vpc:952a6224-ed83-4870-9226-c8f97ac25b8e",
            vpc_name="HL_VPC_Dec_4",
        )
        assert_matches_type(VpcDetail, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_retrieve_vpc(self, async_client: AsyncKrutrimClient) -> None:
        response = await async_client.highlvlvpc.with_raw_response.retrieve_vpc(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = await response.parse()
        assert_matches_type(VpcDetail, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_retrieve_vpc(self, async_client: AsyncKrutrimClient) -> None:
        async with async_client.highlvlvpc.with_streaming_response.retrieve_vpc(
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = await response.parse()
            assert_matches_type(VpcDetail, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    
    @pytest.mark.skip()
    @parametrize
    async def test_method_search_instances(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.search_instances(
            vpc_id="krn:vpc:Colo1-qa:0005604999:718a1c1c-55db-47c7-8b01-bd5f44d8e076:vpc:d5e2c968-9db4-4c05-99fc-293107c33f3e",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
            x_user_email="dev@stainless.com",
        )
        assert_matches_type(InstanceInfoList, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_search_instances_with_all_params(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.search_instances(
            vpc_id="krn:vpc:Colo1-qa:0005604999:718a1c1c-55db-47c7-8b01-bd5f44d8e076:vpc:d5e2c968-9db4-4c05-99fc-293107c33f3e",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
            x_user_email="dev@stainless.com",
            limit=1,
            page=1,
            ip_fixed="20.169.1.5",
            ip_floating="100.20.30.40",
            krn="krn:vm:Colo1-qa:0005604999:718a1c1c-55db-47c7-8b01-bd5f44d8e076:instance:d84de151-9086-4c66-aa3b-cb615fc1d747",
            name="vm_jan_3_exp-1",
        )
        assert_matches_type(InstanceInfoList, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_search_instances(self, async_client: AsyncKrutrimClient) -> None:
        response = await async_client.highlvlvpc.with_raw_response.search_instances(
            vpc_id="krn:vpc:Colo1-qa:0005604999:718a1c1c-55db-47c7-8b01-bd5f44d8e076:vpc:d5e2c968-9db4-4c05-99fc-293107c33f3e",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
            x_user_email="dev@stainless.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = await response.parse()
        assert_matches_type(InstanceInfoList, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_search_instances(self, async_client: AsyncKrutrimClient) -> None:
        async with async_client.highlvlvpc.with_streaming_response.search_instances(
            vpc_id="krn:vpc:Colo1-qa:0005604999:718a1c1c-55db-47c7-8b01-bd5f44d8e076:vpc:d5e2c968-9db4-4c05-99fc-293107c33f3e",
            k_customer_id="k-customer-id",
            x_account_id="acc-1234567890",
            x_user_email="dev@stainless.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = await response.parse()
            assert_matches_type(InstanceInfoList, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_search_networks(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.search_networks(
            vpc_id="vpc_id",
            x_account_id="acc-1234567890",
        )
        assert_matches_type(HighlvlvpcSearchNetworksResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_search_networks(self, async_client: AsyncKrutrimClient) -> None:
        response = await async_client.highlvlvpc.with_raw_response.search_networks(
            vpc_id="vpc_id",
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = await response.parse()
        assert_matches_type(HighlvlvpcSearchNetworksResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_search_networks(self, async_client: AsyncKrutrimClient) -> None:
        async with async_client.highlvlvpc.with_streaming_response.search_networks(
            vpc_id="vpc_id",
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = await response.parse()
            assert_matches_type(HighlvlvpcSearchNetworksResponse, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_search_ports(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.search_ports(
            x_account_id="acc-1234567890",
        )
        assert_matches_type(HighlvlvpcSearchPortsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_search_ports_with_all_params(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.search_ports(
            x_account_id="acc-1234567890",
            name="name",
            network_id="network_id",
            page=1,
            port_id="port_id",
            size=1,
            status="status",
            vpc_id="vpc_id",
        )
        assert_matches_type(HighlvlvpcSearchPortsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_search_ports(self, async_client: AsyncKrutrimClient) -> None:
        response = await async_client.highlvlvpc.with_raw_response.search_ports(
            x_account_id="acc-1234567890",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = await response.parse()
        assert_matches_type(HighlvlvpcSearchPortsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_search_ports(self, async_client: AsyncKrutrimClient) -> None:
        async with async_client.highlvlvpc.with_streaming_response.search_ports(
            x_account_id="acc-1234567890",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = await response.parse()
            assert_matches_type(HighlvlvpcSearchPortsResponse, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_search_vpcs(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.search_vpcs()
        assert_matches_type(HighlvlvpcSearchVpcsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_search_vpcs_with_all_params(self, async_client: AsyncKrutrimClient) -> None:
        highlvlvpc = await async_client.highlvlvpc.search_vpcs(
            name="name",
            page=1,
            size=1,
            status="status",
        )
        assert_matches_type(HighlvlvpcSearchVpcsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_search_vpcs(self, async_client: AsyncKrutrimClient) -> None:
        response = await async_client.highlvlvpc.with_raw_response.search_vpcs()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        highlvlvpc = await response.parse()
        assert_matches_type(HighlvlvpcSearchVpcsResponse, highlvlvpc, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_search_vpcs(self, async_client: AsyncKrutrimClient) -> None:
        async with async_client.highlvlvpc.with_streaming_response.search_vpcs() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            highlvlvpc = await response.parse()
            assert_matches_type(HighlvlvpcSearchVpcsResponse, highlvlvpc, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .kks import (
    KksResource,
    AsyncKksResource,
    KksResourceWithRawResponse,
    AsyncKksResourceWithRawResponse,
    KksResourceWithStreamingResponse,
    AsyncKksResourceWithStreamingResponse,
)
from .clusters import (
    ClustersResource,
    AsyncClustersResource,
    ClustersResourceWithRawResponse,
    AsyncClustersResourceWithRawResponse,
    ClustersResourceWithStreamingResponse,
    AsyncClustersResourceWithStreamingResponse,
)

__all__ = [
    "ClustersResource",
    "AsyncClustersResource",
    "ClustersResourceWithRawResponse",
    "AsyncClustersResourceWithRawResponse",
    "ClustersResourceWithStreamingResponse",
    "AsyncClustersResourceWithStreamingResponse",
    "KksResource",
    "AsyncKksResource",
    "KksResourceWithRawResponse",
    "AsyncKksResourceWithRawResponse",
    "KksResourceWithStreamingResponse",
    "AsyncKksResourceWithStreamingResponse",
]



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()

api_key = os.getenv("api_key")

client = KrutrimClient(api_key = api_key)


try:
    start_stop_VM_resp = client.startStopVM.perform_action(
        instance_krn = "Enter the VM ID",
        x_region = "Enter the region",
        action = "Enter the action start/stop",
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
        timeout = 50000,
    )

    print(f"Success!")

except Exception as e:
    print(f"Exception has occured {e}")


# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Annotated, TypedDict, Required

from ..._types import SequenceNotStr
from ..._utils import PropertyInfo
from .policy_param import PolicyParam
from .volume_param import VolumeParam

__all__ = ["V1CreateAsgParams"]


class V1CreateAsgParams(TypedDict, total=False):
    asg_name: Required[str]

    image_krn: Required[str]

    instance_name: Required[Annotated[str, PropertyInfo(alias="instanceName")]]

    body_instance_type_1: Required[Annotated[str, PropertyInfo(alias="instanceType")]]

    instance_type_id: Required[Annotated[str, PropertyInfo(alias="instanceTypeId")]]

    max: Required[int]

    min: Required[int]

    network_krn: Required[str]

    region: Required[str]

    sshkey_name: Required[str]

    subnet_id: Required[str]

    volume_type: Required[Annotated[str, PropertyInfo(alias="volumeType")]]
    """Root / default volume type"""

    vpc_krn: Required[str]

    x_region: Required[Annotated[str, PropertyInfo(alias="x-region")]]

    attach_floating_ip: bool

    boot_volume_size: Annotated[str, PropertyInfo(alias="bootVolumeSize")]

    body_instance_type_2: Annotated[str, PropertyInfo(alias="instance_type")]

    launch_from_template: bool

    policy: Iterable[PolicyParam]

    body_save_as_template_1: Annotated[bool, PropertyInfo(alias="save_as_template")]

    body_save_as_template_2: Annotated[bool, PropertyInfo(alias="saveAsTemplate")]

    security_group_rules_name: str

    security_group_rules_port: str

    security_group_rules_protocol: str

    security_groups: SequenceNotStr[str]

    tags: Iterable[object]

    template_name: str

    vm_volume_disk_size: str

    volume_name: Annotated[str, PropertyInfo(alias="volumeName")]

    volume_size: Annotated[Iterable[VolumeParam], PropertyInfo(alias="volumeSize")]

    vpc_name: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .vpc import (
    VpcResource,
    AsyncVpcResource,
    VpcResourceWithRawResponse,
    AsyncVpcResourceWithRawResponse,
    VpcResourceWithStreamingResponse,
    AsyncVpcResourceWithStreamingResponse,
)
from .zone import (
    ZoneResource,
    AsyncZoneResource,
    ZoneResourceWithRawResponse,
    AsyncZoneResourceWithRawResponse,
    ZoneResourceWithStreamingResponse,
    AsyncZoneResourceWithStreamingResponse,
)

__all__ = [
    "VpcResource",
    "AsyncVpcResource",
    "VpcResourceWithRawResponse",
    "AsyncVpcResourceWithRawResponse",
    "VpcResourceWithStreamingResponse",
    "AsyncVpcResourceWithStreamingResponse",
    "ZoneResource",
    "AsyncZoneResource",
    "ZoneResourceWithRawResponse",
    "AsyncZoneResourceWithRawResponse",
    "ZoneResourceWithStreamingResponse",
    "AsyncZoneResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import TypedDict

__all__ = ["VpcRemoveParams", "Vpcinfo"]


class VpcRemoveParams(TypedDict, total=False):
    vpcinfo: Iterable[Vpcinfo]


class Vpcinfo(TypedDict, total=False):
    subnetid: str

    vpcid: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, Annotated, TypedDict

from krutrim_client._utils import PropertyInfo

__all__ = ["HighlvlCreateLoadBalancerOrchestrationParams"]


class HighlvlCreateLoadBalancerOrchestrationParams(TypedDict, total=False):
    k_customer_id: Required[Annotated[str, PropertyInfo(alias="k-customer-id")]]

    x_account_id: Required[Annotated[str, PropertyInfo(alias="x-account-id")]]

    x_region: Required[Annotated[str, PropertyInfo(alias="x-region")]]

    listeners: Iterable[object]

    loadbalancer_data: object


# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, NOT_GIVEN
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.kks.clusters import addon_install_params

__all__ = ["AddonsResource", "AsyncAddonsResource"]


class AddonsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AddonsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/kks-python#accessing-raw-response-data-eg-headers
        """
        return AddonsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AddonsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/kks-python#with_streaming_response
        """
        return AddonsResourceWithStreamingResponse(self)

    def list(
        self,
        cluster_krn: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        List Cluster Addons

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/v1/kks/clusters/{cluster_krn}/addons",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


    def retrieve(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        List Cluster Addons

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/v1/kks/addons",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


    def delete(
        self,
        addon_krn: str,
        *,
        cluster_krn: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete Addon

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        if not addon_krn:
            raise ValueError(f"Expected a non-empty value for `addon_krn` but received {addon_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/v1/kks/clusters/{cluster_krn}/addons/{addon_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def install(
        self,
        cluster_krn: str,
        *,
        addon_name: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Install Addon

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            f"/v1/kks/clusters/{cluster_krn}/addons",
            body=maybe_transform({"addon_name": addon_name}, addon_install_params.AddonInstallParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncAddonsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAddonsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/kks-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAddonsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAddonsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/kks-python#with_streaming_response
        """
        return AsyncAddonsResourceWithStreamingResponse(self)

    async def list(
        self,
        cluster_krn: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        List Cluster Addons

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/v1/kks/clusters/{cluster_krn}/addons",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


    async def retrieve(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        List Cluster Addons

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/v1/kks/addons",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


    async def delete(
        self,
        addon_krn: str,
        *,
        cluster_krn: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete Addon

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        if not addon_krn:
            raise ValueError(f"Expected a non-empty value for `addon_krn` but received {addon_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/v1/kks/clusters/{cluster_krn}/addons/{addon_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def install(
        self,
        cluster_krn: str,
        *,
        addon_name: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Install Addon

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            f"/v1/kks/clusters/{cluster_krn}/addons",
            body=await async_maybe_transform({"addon_name": addon_name}, addon_install_params.AddonInstallParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AddonsResourceWithRawResponse:
    def __init__(self, addons: AddonsResource) -> None:
        self._addons = addons

        self.list = to_raw_response_wrapper(
            addons.list,
        )
        self.delete = to_raw_response_wrapper(
            addons.delete,
        )
        self.install = to_raw_response_wrapper(
            addons.install,
        )
        self.retrieve = to_raw_response_wrapper(
            addons.retrieve,
        )


class AsyncAddonsResourceWithRawResponse:
    def __init__(self, addons: AsyncAddonsResource) -> None:
        self._addons = addons

        self.list = async_to_raw_response_wrapper(
            addons.list,
        )
        self.delete = async_to_raw_response_wrapper(
            addons.delete,
        )
        self.install = async_to_raw_response_wrapper(
            addons.install,
        )
        self.retrieve = async_to_raw_response_wrapper(
            addons.retrieve,
        )


class AddonsResourceWithStreamingResponse:
    def __init__(self, addons: AddonsResource) -> None:
        self._addons = addons

        self.list = to_streamed_response_wrapper(
            addons.list,
        )
        self.delete = to_streamed_response_wrapper(
            addons.delete,
        )
        self.install = to_streamed_response_wrapper(
            addons.install,
        )
        self.retrieve = to_streamed_response_wrapper(
            addons.retrieve,
        )


class AsyncAddonsResourceWithStreamingResponse:
    def __init__(self, addons: AsyncAddonsResource) -> None:
        self._addons = addons

        self.list = async_to_streamed_response_wrapper(
            addons.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            addons.delete,
        )
        self.install = async_to_streamed_response_wrapper(
            addons.install,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            addons.retrieve,
        )



from typing import List, Optional
from datetime import datetime
from typing_extensions import TypeAlias

from pydantic import Field as FieldInfo

from krutrim_client._models import BaseModel


__all__ = ["AccessKeyListResponse", "AccessKeyListResponseItem"]


class AccessKeyListResponseItem(BaseModel):
    access_key_id: Optional[str] = FieldInfo(alias="access_key_id", default=None)
    """The ID of the access key."""

    created_at: Optional[datetime] = None
    """Timestamp when the access key was created."""

    key_name: Optional[str] = None
    """The name given to the access key."""

    status: Optional[str] = None
    """The status of the access key (e.g., Active, Inactive)."""


AccessKeyListResponse: TypeAlias = List[AccessKeyListResponseItem]




from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["Source"]


class Source(BaseModel):
    id: str
    """KRN or ID of the source (image, volume, or snapshot)."""

    type: Literal["image", "volume", "snapshot"]
    """Type of source."""



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    
    get_cluster_details = client.kks.clusters.with_raw_response.retrieve(
        cluster_krn = "enter the cluster krn",
    )

    print(f"Successfully fetched the cluster details {get_cluster_details.json()}")

except Exception as e:
    print(f"Exception: {e}")



import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)


try:
    
    get_tag_value = client.tags.with_raw_response.getTagValue(
        cert_id = "Enter the Certificate ID",
        tag_name = "Enter the Tag Name"
    )

    
    print(f"{get_tag_value.json()}")

except Exception as e:
    print(f"Error has occurred: {e}")


import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    
    
    delete_access_keys_resp = client.kos.accessKeys.delete_access_keys(
        access_key_id = "enter the access_key_id",
        x_region_id="enter the region_id",  
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    
    ) 
    print(f"Successfully deleted access key: {delete_access_keys_resp}")


except Exception as e:
    print(f"Error has occurred: {e}")



from __future__ import annotations

from typing_extensions import Literal

import httpx

from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven, NoneType
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from ..types.sshkey import sshkey_create_params
from .._resource import SyncAPIResource, AsyncAPIResource
from .._base_client import make_request_options

from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)

from ..types.sshkey.sshkey_create_response import SshkeyCreateResponse
from ..types.sshkey.sshkey_retrieve_response import SshkeyRetrieveResponse

__all__ = ["SshkeysResource", "AsyncSshkeysResource"]


class SshkeysResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SshkeysResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        """
        return SshkeysResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SshkeysResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        """
        return SshkeysResourceWithStreamingResponse(self)

    def create_sshkey(
        self,
        *,
        key_name: str,
        public_key: str,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SshkeyCreateResponse:
        """Add a new SSH key

        Args:
          key_name: The name for the SSH key.

        Must be unique.

          public_key: The actual public SSH key string (e.g., starting with "ssh-rsa").

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return self._post(
            "/v1/sshkeys",
            body=maybe_transform(
                {
                    "key_name": key_name,
                    "public_key": public_key,
                },
                sshkey_create_params.SshkeyCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SshkeyCreateResponse,
        )

    def retrieve_sshkey(
        self,
        ssh_key_identifier: str,
        x_region: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SshkeyRetrieveResponse:
        """
        Fetch an SSH key by its unique identifier

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not ssh_key_identifier:
            raise ValueError(f"Expected a non-empty value for `ssh_key_identifier` but received {ssh_key_identifier!r}")
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return self._get(
            f"/v1/sshkeys/{ssh_key_identifier}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SshkeyRetrieveResponse,
        )

    def delete_sshkey(
        self,
        ssh_key_identifier: str,
        *,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete a specific SSH key by its UUID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not ssh_key_identifier:
            raise ValueError(f"Expected a non-empty value for `ssh_key_identifier` but received {ssh_key_identifier!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"x-region": x_region})
        return self._delete(
            f"/v1/sshkeys/{ssh_key_identifier}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

class AsyncSshkeysResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSshkeysResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        """
        return AsyncSshkeysResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSshkeysResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.
        """
        return AsyncSshkeysResourceWithStreamingResponse(self)

    async def create_sshkey(
        self,
        *,
        key_name: str,
        public_key: str,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SshkeyCreateResponse:
        """Add a new SSH key

        Args:
          key_name: The name for the SSH key.

        Must be unique.

          public_key: The actual public SSH key string (e.g., starting with "ssh-rsa").

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return await self._post(
            "/v1/sshkeys",
            body=await async_maybe_transform(
                {
                    "key_name": key_name,
                    "public_key": public_key,
                },
                sshkey_create_params.SshkeyCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SshkeyCreateResponse,
        )
    
    async def retrieve_sshkey(
        self,
        ssh_key_identifier: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SshkeyRetrieveResponse:
        """
        Fetch an SSH key by its unique identifier

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not ssh_key_identifier:
            raise ValueError(f"Expected a non-empty value for `ssh_key_identifier` but received {ssh_key_identifier!r}")
        return await self._get(
            f"/v1/sshkeys/{ssh_key_identifier}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SshkeyRetrieveResponse,
        )

    async def delete_sshkey(
        self,
        ssh_key_identifier: str,
        *,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete a specific SSH key by its UUID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not ssh_key_identifier:
            raise ValueError(f"Expected a non-empty value for `ssh_key_identifier` but received {ssh_key_identifier!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"x-region": x_region})
        return await self._delete(
            f"/v1/sshkeys/{ssh_key_identifier}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class SshkeysResourceWithRawResponse:
    def __init__(self, sshkeys: SshkeysResource) -> None:
        self._sshkeys = sshkeys

        self.create_sshkey = to_raw_response_wrapper(
            sshkeys.create_sshkey,
        )
        self.retrieve_sshkey = to_raw_response_wrapper(
            sshkeys.retrieve_sshkey,
        )
        self.delete_sshkey = to_raw_response_wrapper(
            sshkeys.delete_sshkey,
        )

class AsyncSshkeysResourceWithRawResponse:
    def __init__(self, sshkeys: AsyncSshkeysResource) -> None:
        self._sshkeys = sshkeys

        self.create_sshkey = async_to_raw_response_wrapper(
            sshkeys.create_sshkey,
        )
        self.retrieve_sshkey = async_to_raw_response_wrapper(
            sshkeys.retrieve_sshkey,
        )
        self.delete_sshkey = async_to_raw_response_wrapper(
            sshkeys.delete_sshkey,
        )

class SshkeysResourceWithStreamingResponse:
    def __init__(self, sshkeys: SshkeysResource) -> None:
        self._sshkeys = sshkeys

        self.create_sshkey = to_streamed_response_wrapper(
            sshkeys.create_sshkey,
        )

        self.retrieve_sshkey = to_streamed_response_wrapper(
            sshkeys.retrieve_sshkey,
        )
        self.delete_sshkey = to_streamed_response_wrapper(
            sshkeys.delete_sshkey,
        )

class AsyncSshkeysResourceWithStreamingResponse:
    def __init__(self, sshkeys: AsyncSshkeysResource) -> None:
        self._sshkeys = sshkeys

        self.create_sshkey = async_to_streamed_response_wrapper(
            sshkeys.create_sshkey,
        )
        self.retrieve_sshkey = async_to_streamed_response_wrapper(
            sshkeys.retrieve_sshkey,
        )

        self.delete_sshkey = async_to_streamed_response_wrapper(
            sshkeys.delete_sshkey,
        )
        




from __future__ import annotations

from .pod import (
    PodResource,
    AsyncPodResource,
    PodResourceWithRawResponse,
    AsyncPodResourceWithRawResponse,
    PodResourceWithStreamingResponse,
    AsyncPodResourceWithStreamingResponse,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["KpodResource", "AsyncKpodResource"]


class KpodResource(SyncAPIResource):
    @cached_property
    def pod(self) -> PodResource:
        return PodResource(self._client)

    @cached_property
    def with_raw_response(self) -> KpodResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/kpod-python#accessing-raw-response-data-eg-headers
        """
        return KpodResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> KpodResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/kpod-python#with_streaming_response
        """
        return KpodResourceWithStreamingResponse(self)


class AsyncKpodResource(AsyncAPIResource):
    @cached_property
    def pod(self) -> AsyncPodResource:
        return AsyncPodResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncKpodResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/kpod-python#accessing-raw-response-data-eg-headers
        """
        return AsyncKpodResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncKpodResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/kpod-python#with_streaming_response
        """
        return AsyncKpodResourceWithStreamingResponse(self)


class KpodResourceWithRawResponse:
    def __init__(self, kpod: KpodResource) -> None:
        self._kpod = kpod

    @cached_property
    def pod(self) -> PodResourceWithRawResponse:
        return PodResourceWithRawResponse(self._kpod.pod)


class AsyncKpodResourceWithRawResponse:
    def __init__(self, kpod: AsyncKpodResource) -> None:
        self._kpod = kpod

    @cached_property
    def pod(self) -> AsyncPodResourceWithRawResponse:
        return AsyncPodResourceWithRawResponse(self._kpod.pod)


class KpodResourceWithStreamingResponse:
    def __init__(self, kpod: KpodResource) -> None:
        self._kpod = kpod

    @cached_property
    def pod(self) -> PodResourceWithStreamingResponse:
        return PodResourceWithStreamingResponse(self._kpod.pod)


class AsyncKpodResourceWithStreamingResponse:
    def __init__(self, kpod: AsyncKpodResource) -> None:
        self._kpod = kpod

    @cached_property
    def pod(self) -> AsyncPodResourceWithStreamingResponse:
        return AsyncPodResourceWithStreamingResponse(self._kpod.pod)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .cert_list_params import CertListParams as CertListParams
from .cert_import_params import CertImportParams as CertImportParams
from .cert_update_params import CertUpdateParams as CertUpdateParams
from .cert_retrieve_params import CertRetrieveParams as CertRetrieveParams
from .cert_get_expiring_params import CertGetExpiringParams as CertGetExpiringParams


from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()

api_key = os.getenv("api_key")

client = KrutrimClient(api_key = api_key)

try:
    delete_sshkey_resp = client.sshkey.delete_sshkey(
        ssh_key_identifier = "Enter the uuid associated to your ssh key which you want to delete",
        x_region = "Enter the region"
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )
    print("Successfully deleted the SSH Key")

except Exception as e:
    print(f"Exception has occured {e}")


from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ..._types import FileTypes
from ..._utils import PropertyInfo

__all__ = ["CertImportParams"]


class CertImportParams(TypedDict, total=False):
    cert_file: Annotated[FileTypes, PropertyInfo(alias="certFile")]

    flag: str

    name: str

    tags: str


from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    
    create_image_response = client.highlvlvpc.create_image(
        name="enter the name", 
        instance_krn="enter the instance krn",  
        x_region="enter the region",
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"  
       
    )

    print(f"Successfully created the image: {create_image_response}")

except Exception as e:
    print(f"Exception: {e}")



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    
    create_cluster = client.kks.clusters.with_raw_response.create(
        vpcKrn = "enter the vpc krn",
        subnetKrns = "enter the subnetkrn",
        podIpv4Cidr = "enter the cidr",
        serviceIpv4Cidr = "enter the cidr",
        name ="enter the name",
        version = "enter the version",
    )

    print(f"Successfully created the cluster {create_cluster.json()}")

except Exception as e:
    print(f"Exception: {e}")







from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from krutrim_client._utils import PropertyInfo

__all__ = ["V1DetachRuleParams"]


class V1DetachRuleParams(TypedDict, total=False):
    ruleid: Required[str]
    """KRN of the Security Group Rule."""

    securityid: Required[str]
    """KRN of the Security Group to attach/detach the rule from."""

    vpcid: Required[str]
    """KRN of the VPC associated with the Security Group and rule."""

    k_customer_id: Required[Annotated[str, PropertyInfo(alias="K-Customer-ID")]]

    x_account_id: Required[Annotated[str, PropertyInfo(alias="x-account-id")]]



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    
    add_record = client.v1.record.create(


        krnid = "enter krn id ",
        rname = "enter record name ",
        value = "enter the value",                             #example 10.1.1.1
        ttl = 5,                                               #change as per requirement
        TYPE = "A"                                             #change as per requirement
    )

    print(f"Successfully added the record")

except Exception as e:
    print(f"Exception: {e}")





from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["ImageMachineParams"]


class ImageMachineParams(TypedDict, total=False):
    disk_format: Required[Annotated[str, PropertyInfo(alias="diskFormat")]]
    """The format of the disk image."""

    image: Required[str]
    """A URL to the image file."""


import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient

# Load env
load_dotenv()
api_key = os.getenv("API_KEY")

# Init client
client = KrutrimClient(api_key=api_key)
try:
    resp = client.lb.with_raw_response.update_target_group(
        x_region="enter the x_region",
        # x_region possible values "In-Bangalore-1"
        target_group_name="enter target group name",
        k_customer_id="enter the k_customer_id",
        x_account_id="enter the x_account_id",
        vpc_id="enter vpc id",
        body_lb_krn="enter lb krn here",
        members=[],
        health_monitor={}
    )
    print("Response:", resp.json())
except Exception as e:
    print(f"Error has occurred: {e}")




            # {
            # "name": "member_test_celery_1_10",
            # "address": "10.230.166.233",
            # "protocol_port": 3000,
            # "weight": 1
            # },
            # {
            # "name": "member_test_celery_2_10",
            # "address": "10.0.4.175",
            # "protocol_port": 5000,
            # "weight": 1
            # }



        # "h_type": "HTTP",
        # "timeout": 10,
        # "delay": 13,
        # "name": "LB-fullaccess-HM",
        # "url_path": "/",
        # "max_retries": 2


from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()

api_key = os.getenv("api_key")

client = KrutrimClient(api_key = api_key)


try:
    list_vpc_response = client.securityGroup.list_by_vpc(
        vpc_krn_identifier = "Enter the VPC ID under which you want to find the List of Security Group",
        x_region = "Enter the region"
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )

    print(f"Successfully fetched the Security Group List {list_vpc_response}")
except Exception as e:
    print(f"Exception has occured {e}")


from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    
    retrive_kubeconfig = client.kks.clusters.with_raw_response.retrieve_kubeconfig(
        cluster_krn = "krn:kks:In-Bangalore-1:6419347276:df18aa35-b845-4e61-b739-32a3a4e219d3:cluster:0951ed93-9e4d-48a7-871e-31837577c41d"
    )

    print(f"Successfully Retrived Kubeconfig {retrive_kubeconfig.text()}")

except Exception as e:
    print(f"Exception: {e}")


from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()

api_key = os.getenv("api_key")

client = KrutrimClient(api_key = api_key)


try:
    get_sshkey_response = client.sshkey.retrieve_sshkey(
        ssh_key_identifier = "0070140197",
        x_region = "In-Bangalore-1"
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )
    print(f"Successfully retrieve the SSH Key List {get_sshkey_response}!")
except Exception as e:
    print(f"Exception! {e}")


# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import TypedDict

__all__ = ["RecordCreateParams", "Record"]


class RecordCreateParams(TypedDict, total=False):
    krnid: str

    records: Iterable[Record]

    rname: str

    routing: str

    ttl: int

    type: str


class Record(TypedDict, total=False):
    value: str

    weight: int



from __future__ import annotations
from typing_extensions import Required, Annotated, TypedDict
from ..._utils import PropertyInfo

__all__ = ["HighlvlvpcDeleteImageParams"]

class HighlvlvpcDeleteImageParams(TypedDict, total=False):
    snapshot_krn: Required[str]
    """The KRN of the image to delete."""




# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["AsgGetAsgKrnByVpcParams"]


class AsgGetAsgKrnByVpcParams(TypedDict, total=False):
    page: Required[int]

    size: Required[int]

    vpc_krn: Required[str]



from typing import Optional

from ..._models import BaseModel

__all__ = ["GenericSuccessResponse"]


class GenericSuccessResponse(BaseModel):
    message: Optional[str] = None
    """A confirmation message."""

    status: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .sshkey_create_params import SshkeyCreateParams as SshkeyCreateParams
from .sshkey_create_response import SshkeyCreateResponse as SshkeyCreateResponse
from .sshkey_retrieve_response import SshkeyRetrieveResponse as SshkeyRetrieveResponse



from typing import Optional

from ..._models import BaseModel

__all__ = ["Qos", "Bandwidth", "Iops"]


class Bandwidth(BaseModel):
    read_bytes_sec: int
    """Read bandwidth in bytes per second."""

    write_bytes_sec: int
    """Write bandwidth in bytes per second."""


class Iops(BaseModel):
    read_iops_sec: int
    """Read IOPS per second."""

    write_iops_sec: int
    """Write IOPS per second."""


class Qos(BaseModel):
    bandwidth: Optional[Bandwidth] = None
    """Bandwidth settings for QoS."""

    iops: Optional[Iops] = None
    """IOPS settings for QoS."""



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()

api_key = os.getenv("api_key")

client = KrutrimClient(api_key = api_key)

try:
    create_volume_resp = client.kbs.create_volume(
        availability_zone = "nova",
        multiattach = True,
        name = "Enter the Volume Name",
        size = 20,
        volumetype = "HNSS",
        k_tenant_id = "Enter the VPC ID",
        description = "Enter the Description",
        x_region = "Enter the region",
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )
    print(f"Created the Volume: {create_volume_resp}")
except Exception as e:
    print(f"Exception has occured:  {e}")







from __future__ import annotations

from typing import Iterable
from typing_extensions import Literal

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.kpod import pod_create_params, pod_update_params
from ..._base_client import make_request_options

from ...types.kpod.pod_create_response import PodCreateResponse
from ...types.kpod.pod_delete_response import PodDeleteResponse
from ...types.kpod.pod_update_response import PodUpdateResponse

__all__ = ["PodResource", "AsyncPodResource"]


class PodResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> PodResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/kpod-python#accessing-raw-response-data-eg-headers
        """
        return PodResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PodResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/kpod-python#with_streaming_response
        """
        return PodResourceWithStreamingResponse(self)
    def validate_create_pod_params(self, *, container_disk_size: str, expose_http_ports: str, expose_tcp_ports: str,
                                         flavor_name: str, pod_name: str, pod_template_id: int, region: str,
                                         sshkey_name: str, volume_disk_size: str, volume_mount_path: str) -> None:
        """
        Validate parameters for creating a pod.
        """
        # Validate the disk size
        if not isinstance(container_disk_size, str) or not container_disk_size.strip():
            raise ValueError("'container_disk_size' must be a non-empty string.")
        
        # Validate the ports
        if not isinstance(expose_http_ports, str) or not expose_http_ports.strip():
            raise ValueError("'expose_http_ports' must be a non-empty string.")
        if not isinstance(expose_tcp_ports, str) or not expose_tcp_ports.strip():
            raise ValueError("'expose_tcp_ports' must be a non-empty string.")
        
        # Validate flavor name
        if not isinstance(flavor_name, str) or not flavor_name.strip():
            raise ValueError("'flavor_name' must be a non-empty string.")
        
        # Validate pod name
        if not isinstance(pod_name, str) or not pod_name.strip():
            raise ValueError("'pod_name' must be a non-empty string.")
        
        # Validate pod template ID
        if not isinstance(pod_template_id, int):
            raise ValueError("'pod_template_id' must be an integer.")
        
        # Validate region
        if not isinstance(region, str) or not region.strip():
            raise ValueError("'region' must be a non-empty string.")
        
        # Validate SSH key name
        if not isinstance(sshkey_name, str) or not sshkey_name.strip():
            raise ValueError("'sshkey_name' must be a non-empty string.")
        
        # Validate volume disk size
        if not isinstance(volume_disk_size, str) or not volume_disk_size.strip():
            raise ValueError("'volume_disk_size' must be a non-empty string.")
        
        # Validate volume mount path
        if not isinstance(volume_mount_path, str) or not volume_mount_path.strip():
            raise ValueError("'volume_mount_path' must be a non-empty string.")

    def validate_delete_pod_params(self, *, kpod_krn: str) -> None:
        """
        Validate parameters for deleting a pod.
        """
        if not isinstance(kpod_krn, str) or not kpod_krn.strip():
            raise ValueError("'kpod_krn' must be a non-empty string.")
        
    def validate_update_pod_params(self, *, kpod_krn: str, action: str) -> None:
        """
        Validate parameters for updating a pod.
        Ensures the pod KRN is a non-empty string and the action is one of "start", "stop", or "restart".
        """
    # Validate the KRN (Krutrim Resource Name) of the pod
        if not isinstance(kpod_krn, str) or not kpod_krn.strip():
            raise ValueError("'kpod_krn' must be a non-empty string.")
    
    # Validate the action to ensure it's one of "start", "stop", or "restart"
        valid_actions = ["start", "stop", "restart"]
        if action not in valid_actions:
            raise ValueError(f"Invalid action: '{action}'. Must be one of {valid_actions}.")
        
    def create(
        self,
        *,
        container_disk_size: str,
        expose_http_ports: str,
        expose_tcp_ports: str,
        flavor_name: str,
        has_encrypt_volume: bool,
        has_jupyter_notebook: bool,
        has_ssh_access: bool,
        pod_name: str,
        pod_template_id: int,
        region: str,
        sshkey_name: str,
        volume_disk_size: str,
        volume_mount_path: str,
        environment_variables: Iterable[object] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PodCreateResponse:
        """
        Create a new pod

        Args:
          container_disk_size: The size of the container disk in GB.

          expose_http_ports: Comma-separated list of HTTP ports to expose (e.g., "8888").

          expose_tcp_ports: Comma-separated list of TCP ports to expose (e.g., "22").

          flavor_name: The name of the flavor/instance type for the pod (e.g., GPU type).

          has_encrypt_volume: Indicates if the volume should be encrypted.

          has_jupyter_notebook: Indicates if Jupyter Notebook should be enabled.

          has_ssh_access: Indicates if SSH access should be enabled.

          pod_name: Unique name for the pod.

          pod_template_id: The ID of the pod template to use.

          region: The region where the pod should be deployed.

          sshkey_name: The name of the SSH key to associate with the pod.

          volume_disk_size: The size of the attached volume disk in GB.

          volume_mount_path: The path where the volume should be mounted inside the pod.

          environment_variables: List of environment variables to set in the pod.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_create_pod_params(
            container_disk_size=container_disk_size,
            expose_http_ports=expose_http_ports,
            expose_tcp_ports=expose_tcp_ports,
            flavor_name=flavor_name,
            pod_name=pod_name,
            pod_template_id=pod_template_id,
            region=region,
            sshkey_name=sshkey_name,
            volume_disk_size=volume_disk_size,
            volume_mount_path=volume_mount_path
        )
        return self._post(
            "/v1/kpod/pod",
            body=maybe_transform(
                {
                    "container_disk_size": container_disk_size,
                    "expose_http_ports": expose_http_ports,
                    "expose_tcp_ports": expose_tcp_ports,
                    "flavor_name": flavor_name,
                    "has_encrypt_volume": has_encrypt_volume,
                    "has_jupyter_notebook": has_jupyter_notebook,
                    "has_ssh_access": has_ssh_access,
                    "pod_name": pod_name,
                    "pod_template_id": pod_template_id,
                    "region": region,
                    "sshkey_name": sshkey_name,
                    "volume_disk_size": volume_disk_size,
                    "volume_mount_path": volume_mount_path,
                    "environment_variables": environment_variables,
                },
                pod_create_params.PodCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PodCreateResponse,
        )

    def update(
        self,
        kpod_krn: str,
        *,
        action: Literal["start", "stop", "restart"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PodUpdateResponse:
        """
        Perform an action (e.g., start, stop, restart) on a specific kpod.

        Args:
          kpod_krn: The KRN (Krutrim Resource Name) of the kpod to perform the action on.

          action: The action to perform on the kpod.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_update_pod_params(kpod_krn=kpod_krn, action=action)
        if not kpod_krn:
            raise ValueError(f"Expected a non-empty value for `kpod_krn` but received {kpod_krn!r}")
        
        return self._put(
            f"/v1/kpod/pod/{kpod_krn}",
            body=maybe_transform({"action": action}, pod_update_params.PodUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PodUpdateResponse,
        )

    def delete(
        self,
        kpod_krn: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PodDeleteResponse:
        """
        Delete a specific kpod

        Args:
          kpod_krn: The KRN (Krutrim Resource Name) of the kpod to delete.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        
        if not kpod_krn:
            raise ValueError(f"Expected a non-empty value for `kpod_krn` but received {kpod_krn!r}")
        self.validate_delete_pod_params(kpod_krn=kpod_krn)    
        return self._delete(
            f"/v1/kpod/pod/{kpod_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PodDeleteResponse,
        )


class AsyncPodResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncPodResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/kpod-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPodResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPodResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/kpod-python#with_streaming_response
        """
        return AsyncPodResourceWithStreamingResponse(self)
    async def validate_create_pod_params(self, *, container_disk_size: str, expose_http_ports: str, expose_tcp_ports: str,
                                         flavor_name: str, pod_name: str, pod_template_id: int, region: str,
                                         sshkey_name: str, volume_disk_size: str, volume_mount_path: str) -> None:
        """
        Validate parameters for creating a pod.
        """
        if not isinstance(container_disk_size, str) or not container_disk_size.strip():
            raise ValueError("'container_disk_size' must be a non-empty string.")
        if not isinstance(expose_http_ports, str) or not expose_http_ports.strip():
            raise ValueError("'expose_http_ports' must be a non-empty string.")
        if not isinstance(expose_tcp_ports, str) or not expose_tcp_ports.strip():
            raise ValueError("'expose_tcp_ports' must be a non-empty string.")
        if not isinstance(flavor_name, str) or not flavor_name.strip():
            raise ValueError("'flavor_name' must be a non-empty string.")
        if not isinstance(pod_name, str) or not pod_name.strip():
            raise ValueError("'pod_name' must be a non-empty string.")
        if not isinstance(pod_template_id, int):
            raise ValueError("'pod_template_id' must be an integer.")
        if not isinstance(region, str) or not region.strip():
            raise ValueError("'region' must be a non-empty string.")
        if not isinstance(sshkey_name, str) or not sshkey_name.strip():
            raise ValueError("'sshkey_name' must be a non-empty string.")
        if not isinstance(volume_disk_size, str) or not volume_disk_size.strip():
            raise ValueError("'volume_disk_size' must be a non-empty string.")
        if not isinstance(volume_mount_path, str) or not volume_mount_path.strip():
            raise ValueError("'volume_mount_path' must be a non-empty string.")

    async def validate_delete_pod_params(self, *, kpod_krn: str) -> None:
        """
        Validate parameters for deleting a pod.
        """
        if not isinstance(kpod_krn, str) or not kpod_krn.strip():
            raise ValueError("'kpod_krn' must be a non-empty string.")
    async def validate_update_pod_params(self, *, kpod_krn: str, action: str) -> None:
        """
        Validate parameters for updating a pod.
        Ensures the pod KRN is a non-empty string and the action is one of "start", "stop", or "restart".
        """
    # Validate the KRN (Krutrim Resource Name) of the pod
        if not isinstance(kpod_krn, str) or not kpod_krn.strip():
            raise ValueError("'kpod_krn' must be a non-empty string.")
    
    # Validate the action to ensure it's one of "start", "stop", or "restart"
        valid_actions = ["start", "stop", "restart"]
        if action not in valid_actions:
            raise ValueError(f"Invalid action: '{action}'. Must be one of {valid_actions}.")
        
    async def create(
        self,
        *,
        container_disk_size: str,
        expose_http_ports: str,
        expose_tcp_ports: str,
        flavor_name: str,
        has_encrypt_volume: bool,
        has_jupyter_notebook: bool,
        has_ssh_access: bool,
        pod_name: str,
        pod_template_id: int,
        region: str,
        sshkey_name: str,
        volume_disk_size: str,
        volume_mount_path: str,
        environment_variables: Iterable[object] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PodCreateResponse:
        """
        Create a new pod

        Args:
          container_disk_size: The size of the container disk in GB.

          expose_http_ports: Comma-separated list of HTTP ports to expose (e.g., "8888").

          expose_tcp_ports: Comma-separated list of TCP ports to expose (e.g., "22").

          flavor_name: The name of the flavor/instance type for the pod (e.g., GPU type).

          has_encrypt_volume: Indicates if the volume should be encrypted.

          has_jupyter_notebook: Indicates if Jupyter Notebook should be enabled.

          has_ssh_access: Indicates if SSH access should be enabled.

          pod_name: Unique name for the pod.

          pod_template_id: The ID of the pod template to use.

          region: The region where the pod should be deployed.

          sshkey_name: The name of the SSH key to associate with the pod.

          volume_disk_size: The size of the attached volume disk in GB.

          volume_mount_path: The path where the volume should be mounted inside the pod.

          environment_variables: List of environment variables to set in the pod.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        await self.validate_create_pod_params(
            container_disk_size=container_disk_size,
            expose_http_ports=expose_http_ports,
            expose_tcp_ports=expose_tcp_ports,
            flavor_name=flavor_name,
            pod_name=pod_name,
            pod_template_id=pod_template_id,
            region=region,
            sshkey_name=sshkey_name,
            volume_disk_size=volume_disk_size,
            volume_mount_path=volume_mount_path
        )
        return await self._post(
            "/v1/kpod/pod",
            body=await async_maybe_transform(
                {
                    "container_disk_size": container_disk_size,
                    "expose_http_ports": expose_http_ports,
                    "expose_tcp_ports": expose_tcp_ports,
                    "flavor_name": flavor_name,
                    "has_encrypt_volume": has_encrypt_volume,
                    "has_jupyter_notebook": has_jupyter_notebook,
                    "has_ssh_access": has_ssh_access,
                    "pod_name": pod_name,
                    "pod_template_id": pod_template_id,
                    "region": region,
                    "sshkey_name": sshkey_name,
                    "volume_disk_size": volume_disk_size,
                    "volume_mount_path": volume_mount_path,
                    "environment_variables": environment_variables,
                },
                pod_create_params.PodCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PodCreateResponse,
        )

    async def update(
        self,
        kpod_krn: str,
        *,
        action: Literal["start", "stop", "restart"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PodUpdateResponse:
        """
        Perform an action (e.g., start, stop, restart) on a specific kpod.

        Args:
          kpod_krn: The KRN (Krutrim Resource Name) of the kpod to perform the action on.

          action: The action to perform on the kpod.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        await self.validate_update_pod_params(kpod_krn=kpod_krn, action=action)
        if not kpod_krn:
            raise ValueError(f"Expected a non-empty value for `kpod_krn` but received {kpod_krn!r}")
        return await self._put(
            f"/v1/kpod/pod/{kpod_krn}",
            body=await async_maybe_transform({"action": action}, pod_update_params.PodUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PodUpdateResponse,
        )


    async def delete(
        self,
        kpod_krn: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PodDeleteResponse:
        """
        Delete a specific kpod

        Args:
          kpod_krn: The KRN (Krutrim Resource Name) of the kpod to delete.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        await self.validate_delete_pod_params(kpod_krn=kpod_krn) 
        # if not kpod_krn:
        #     raise ValueError(f"Expected a non-empty value for `kpod_krn` but received {kpod_krn!r}")
           
        return await self._delete(
            f"/v1/kpod/pod/{kpod_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PodDeleteResponse,
        )


class PodResourceWithRawResponse:
    def __init__(self, pod: PodResource) -> None:
        self._pod = pod

        self.create = to_raw_response_wrapper(
            pod.create,
        )
        self.update = to_raw_response_wrapper(
            pod.update,
        )
        self.delete = to_raw_response_wrapper(
            pod.delete,
        )


class AsyncPodResourceWithRawResponse:
    def __init__(self, pod: AsyncPodResource) -> None:
        self._pod = pod

        self.create = async_to_raw_response_wrapper(
            pod.create,
        )
        self.update = async_to_raw_response_wrapper(
            pod.update,
        )
        self.delete = async_to_raw_response_wrapper(
            pod.delete,
        )


class PodResourceWithStreamingResponse:
    def __init__(self, pod: PodResource) -> None:
        self._pod = pod

        self.create = to_streamed_response_wrapper(
            pod.create,
        )
        self.update = to_streamed_response_wrapper(
            pod.update,
        )
        self.delete = to_streamed_response_wrapper(
            pod.delete,
        )


class AsyncPodResourceWithStreamingResponse:
    def __init__(self, pod: AsyncPodResource) -> None:
        self._pod = pod

        self.create = async_to_streamed_response_wrapper(
            pod.create,
        )
        self.update = async_to_streamed_response_wrapper(
            pod.update,
        )
        self.delete = async_to_streamed_response_wrapper(
            pod.delete,
        )




from typing import List, Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel
from .instance_info import InstanceInfo

__all__ = ["InstanceInfoList"]


class InstanceInfoList(BaseModel):
    instances: Optional[List[InstanceInfo]] = None

    page: Optional[int] = None
    """The current page number."""

    page_size: Optional[int] = FieldInfo(alias="pageSize", default=None)
    """The number of items per page."""

    total_count: Optional[int] = FieldInfo(alias="totalCount", default=None)
    """The total number of instances matching the filter."""

    total_pages: Optional[int] = FieldInfo(alias="totalPages", default=None)
    """The total number of pages."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, Annotated, TypedDict

from krutrim_client._utils import PropertyInfo

__all__ = ["HighlvlUpdateTargetGroupParams", "HealthMonitor", "Member"]


class HighlvlUpdateTargetGroupParams(TypedDict, total=False):
    x_region: Required[Annotated[str, PropertyInfo(alias="x-region")]]

    health_monitor: HealthMonitor

    members: Iterable[Member]

    target_group_name: str

    vpc_id: str


class HealthMonitor(TypedDict, total=False):
    delay: int

    h_type: str

    timeout: int

    url_path: str


class Member(TypedDict, total=False):
    address: str

    name: str

    protocol_port: int

    weight: int